@@ -12,7 +12,7 @@ GAopt <- function (OF, algo = list(), ...) {
                   cl = NULL,            ##
                   mc.control = list(),  ##
                   printDetail = TRUE,
-                  printBar = TRUE,
+                  printBar = interactive(),
                   initP = NULL,
                   storeF = TRUE,
                   storeSolutions = FALSE,
