@@ -1,5 +1,57 @@
 ## -*- truncate-lines: t; -*-
 
+Ritter <- function(dest.dir,
+                   url = "https://site.warrington.ufl.edu/ritter/files/IPO-age.xlsx") {
+
+    f.name <- paste0(format(Sys.Date(), "%Y%m%d_"),
+                     "IPO-age.xlsx")
+    f.path <- file.path(normalizePath(dest.dir), f.name)
+
+    if (!file.exists(f.path))
+        dl.result <- download.file(url, destfile = f.path)
+    else
+        dl.result <- 0
+
+    if (dl.result != 0L) {
+        warning("download failed with code ", dl.result, "; see ?download.file")
+        return(invisible(NULL))
+    }
+
+    if (!requireNamespace("openxlsx", quietly = TRUE))
+        stop("file downloaded, but package ",
+             sQuote("openxlsx"), " is not available")
+
+    data <- openxlsx::read.xlsx(f.path)
+    data <- data[, 1:11]
+    colnames(data) <- c("CUSIP","Offer date","Company name",
+                        "Ticker","Founding","PERM","VC dummy",
+                        "Rollup","Dual","Post-issue shares","Internet")
+
+    data[["Offer date"]] <- as.Date(as.character(data[["Offer date"]]),
+                                    format = "%Y%m%d")
+
+    data[["Rollup"]][data[["Rollup"]] %in% c(".")] <- NA
+    data[["Rollup"]] <- as.logical(as.numeric(data[["Rollup"]]))
+
+    data[["Internet"]][data[["Internet"]] %in% c(".")] <- NA
+    data[["Internet"]] <- as.logical(as.numeric(data[["Internet"]]))
+
+    data[["Dual"]][data[["Dual"]] %in% c(".")] <- NA
+    data[["Dual"]] <- as.numeric(data[["Dual"]])
+
+    data[["VC dummy"]][data[["VC dummy"]] %in% c(".")] <- NA
+    data[["VC dummy"]] <- as.numeric(data[["VC dummy"]])
+
+    data[["Post-issue shares"]][data[["Post-issue shares"]] %in% c(".", "-9")] <- NA
+    data[["Post-issue shares"]] <- as.numeric(data[["Post-issue shares"]])
+
+    data[["Founding"]][data[["Founding"]] %in% c(".", "-99", "-9")] <- NA
+    data[["Founding"]] <- as.numeric(data[["Founding"]])
+
+
+    data
+}
+
 Shiller <- function(dest.dir,
                     url = "http://www.econ.yale.edu/~shiller/data/ie_data.xls") {
 
@@ -62,7 +114,6 @@ Shiller <- function(dest.dir,
     data
 }
 
-
 French <- function(dest.dir,
                    dataset = "F-F_Research_Data_Factors_CSV.zip",
                    weighting = "value",
@@ -198,7 +249,11 @@ French <- function(dest.dir,
         ans <- NULL
         for (i in seq_along(txt)) {
             if (grepl("^ ?[0-9]", txt[i])) {
-                ind <- txt[i]
+                ind <- trimws(txt[i])
+                ans <- rbind(ans,
+                             data.frame(Industry = ind,
+                                        Codes = NA,
+                                        stringsAsFactors = FALSE))
             } else if (!grepl("^ *$", txt[i])) {
                 ans <- rbind(ans,
                              data.frame(Industry = ind,
@@ -206,7 +261,8 @@ French <- function(dest.dir,
                                         stringsAsFactors = FALSE))
             }
         }
-        ans$Industry <- trimws(ans$Industry)
+
+        ans$Industry <- ans$Industry
         num <- gsub(" *([0-9]+) .*", "\\1", ans$Industry)
         abbr <- gsub(" *[0-9]+ ([^ ]+) .*", "\\1", ans$Industry)
         industry <- gsub(" *[0-9]+ [^ ]+ (.*)", "\\1", ans$Industry)
@@ -215,7 +271,7 @@ French <- function(dest.dir,
         ans <- data.frame(num = trimws(num),
                           abbr = trimws(abbr),
                           industry = trimws(industry),
-                          industry_group = substr(ans$Codes, 10, 100000),
+                          industry_group = trimws(substr(ans$Codes, 10, 100000)),
                           start = substr(ans$Codes, 1, 4),
                           end   = substr(ans$Codes, 6, 9),
                           stringsAsFactors = FALSE)
